@@ -22,7 +22,11 @@ Xscale=1 #default value X scale in arraXscale index
 value_index=0
 values_total=0
 
+arrLogFiles=[]
+arrLogFileIndex=0
+
 trigger=14 #trigger level for movement
+maxtrigger=100
 
 demo=0
 debug=0
@@ -35,7 +39,6 @@ StopTime=0
 ChangesInGraph=0
 run=0
 Mode=0
-
 version="0"
 build="0"
 user=""
