@@ -25,6 +25,7 @@ import os, os.path
 
 import data #own data
 from myFunctions import * #Own functions
+from myFunctions2 import * #Own functions
 
 #GUIs
 from Ui_StartWindow import *
@@ -51,8 +52,6 @@ def main():
         data.debug=0
 
     #if not on the N900, a acceleration sensor has to be simulated
-#    uname=os.uname()
-#    if(uname[1]=="Nokia-N900"): data.demo=0	#runs on real N900 hardware
     if os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord"): data.demo=0	#runs on real N900 hardware
     else: data.demo=1	#runs on other hardware/OS
 
@@ -76,8 +75,6 @@ def main():
     NoteWindow = frmNoteWindow()
     
     StartWindow.show()      
-#    ShowLogWindow()
-
 
     StartWindow.UpdateScreenStart()
     StartWindow.show()
@@ -101,8 +98,6 @@ def main():
 
 
 
-
-
 ###########################################################################
 #  Gets called every second,
 ###########################################################################
@@ -123,103 +118,35 @@ def TimerLoop():
 #    Show_passed_time("TimerLoop end")
 
   
-  
-  
-  
-###########################################################################
-# Show the collectring window (hera the data gets visualised during the logging)
-###########################################################################
-def ShowCollectingWindow():
-    CollectingWindow.show()
-    StartWindow.hide()
-    data.Mode=0 #run in normal mode
-    ToggleMeasurement()
-    
-    
-###########################################################################
-# Show the collectring window (hera the data gets visualised during the logging)
-###########################################################################
-def ShowCollectingWindowTest():
-    CollectingWindow.show()
-    StartWindow.hide()
-    data.Mode=1 #run in quick mode (for testing only)
-    ToggleMeasurement()
-    data.Xscale=0 #default zoom level
-    data.test=1 #hide axis lables
-    
-    
-  
-###########################################################################
-# Show the log window (her ethe data from a file gets visualised)
-###########################################################################
-def ShowLogWindow():
-    global LogWindowGraph
-    
-    tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
-    tmp2=tmp.split("/")
-    l=len(tmp2)    
-    x=tmp2[l-1]
-    if(x==""): return #only continue if valid log file selected
-    data.logfilename=x
-    
-    LogWindowGraph = LogWindowCanvas()
-#    data.Xscale=1 #default zoom level
-#    LogWindowGraph.show()
-    ShowLogFile()
-    
-    LogWindow.show()
-    StartWindow.hide()
-
-
-
-############################################################################
-## Stretch graph to show more details
-############################################################################
-def ZoomIn():
-    if(data.Xscale==0): return
-    LogWindow.ui.bZoomOut.setEnabled(True)
-    if(data.Xscale==1): LogWindow.ui.bZoomIn.setEnabled(False)
-    else: LogWindow.ui.bZoomIn.setEnabled(True)
-    data.Xscale=(data.Xscale-1) % data.arrXscaleLen
-    ProcessData()
-    Show_passed_time("## ZoomIn")
-    data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    CollectingWindow.update()
-    LogWindow.update()
-
-def ZoomOut():
-    if(data.Xscale==data.arrXscaleLen-1): return
-    LogWindow.ui.bZoomIn.setEnabled(True)
-    if(data.Xscale==data.arrXscaleLen-2): LogWindow.ui.bZoomOut.setEnabled(False)
-    else: LogWindow.ui.bZoomOut.setEnabled(True)
-    data.Xscale=(data.Xscale+1) % data.arrXscaleLen
-    ProcessData()
-    Show_passed_time("## ZoomIn")
-    data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    CollectingWindow.update()
-    LogWindow.update()
-
-
 
 
 
 ###########################################################################
 # Starte the measurement
 ###########################################################################
-def StartMeasurement(interval):
-    global CollectingWindowGraph
+def StartMeasurement():
     global app
-    
     #init value
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
+    data.arrData[0][0]=""
+    
+    if(data.Mode==0):
+        interval=data.sampling #normal
+    else:  
+        interval=10 #Fast mode for testing
+    
+    data.run=1
+    app.timer_GetData = QtCore.QTimer()
+    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
+    app.timer_GetData.start(interval) 
+   
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once    
     
     StartLogfile(interval)
         
-    CollectingWindowGraph = CollectingWindowCanvas()
     data.Xscale=1 #default zoom level
-    CollectingWindowGraph.show()
     
     print "Start timers (Interval:", interval ,"ms)..."
     print "Sampling interval:", interval, "ms"
@@ -228,292 +155,61 @@ def StartMeasurement(interval):
     print "=> log interval:", interval*data.value_smoothing, "ms"
     print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
     
-    app.timer_GetData = QtCore.QTimer()
-    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
-    app.timer_GetData.start(interval)
-    data.run=1
+
     
-    CollectingWindow.UpdateScreenStart()
     
 
 
-
-###########################################################################
-# Stop the measurement
-###########################################################################
-def ToggleMeasurement():
+def StopMeasurement():
     global app
-    if(data.run==0): #not running
-        data.run=1
-        print "data.Mode:",  data.Mode,  data.sampling
-        if(data.Mode==0):
-            StartMeasurement(data.sampling) #normal
-        else:  
-            StartMeasurement(10) #Fast mode for testing
+    data.run=0
+    print "Stop timers..."
+    app.timer_GetData.stop()
+    data.run=0
+    StopLogfile()       
+    data.test=0 # reset test mode if was active
+
+
+
+
+
+
+############################################################################
+## Stretch graph to show more details
+############################################################################
+def Zoom(direction):
+    if(direction==+1): #zoom in
+        if(data.Xscale==0): return
+        LogWindow.ui.bZoomOut.setEnabled(True)
+        data.Xscale=(data.Xscale-1) % data.arrXscaleLen
+        ProcessData()
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    else: # -1, zoom out
+        if(data.Xscale==data.arrXscaleLen-1): return
+        LogWindow.ui.bZoomIn.setEnabled(True)
+        data.Xscale=(data.Xscale+1) % data.arrXscaleLen
+        ProcessData()
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    else: #running
-        data.run=0
-        print "Stop timers..."
-        app.timer_GetData.stop()
-        data.run=0
-        StopLogfile()       
-        CollectingWindow.UpdateScreenStop()
-        data.test=0 # reset test mode if was active
-    
-    
 
 
 
 
-###########################################################################
-# Raise the trigger in the graph + sleep phases
-###########################################################################
-def RaiseTrigger():   
-    data.trigger=data.trigger+1
-    if(data.trigger>100): data.trigger=100
-    ProcessData()
-    data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    CollectingWindow.update()
-    CollectingWindow.UpdateScreen()
-    LogWindow.update() 
-    LogWindow.UpdateScreen()
-    
-   
-   
-
-###########################################################################
-# Lower the trigger in the graph + sleep phases
-###########################################################################
-def LowerTrigger():   
-    data.trigger=data.trigger-1
-    if(data.trigger<0): data.trigger=0
-    ProcessData()
-    data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    CollectingWindow.update()
-    CollectingWindow.UpdateScreen()
-    LogWindow.update()
-    LogWindow.UpdateScreen()
-   
-   
-   
-   
-   
-   
-
-###########################################################################
-# Show (refreshs) the graph.
-# the parameter indcates on which window it will be drawn
-###########################################################################
-def showGraph(self):
-        Show_passed_time("showGraph Start")
-        if(data.ChangesInGraph==0): 
-            if(data.debug==1): print "------>         Do not redraw, nothing changed!"
-            return 
-            
-        data.ChangesInGraph=0
-        paint = QtGui.QPainter()
-        paint.begin(self)
-
-        paint.setFont(QtGui.QFont('Decorative', 12))
-        paint.setPen(QtGui.QColor("gray"))
-        paint.setBrush(QtGui.QColor("black"))
-
-        #show CollectingWindowGraph border
-        paint.drawRect(0,0,781,data.Ysize)           
-
-        Xscale=data.arrXscale[data.Xscale]
-#        print "Zoom level:",  data.Xscale
-
-        x=data.arrDataIndex/Xscale
-        if(x>775): 
-            shift=(x-775)*Xscale
-#            print "Curve too long,  dropping first",  shift,  "values"
-        else: shift=0
-            
-        try:
-            t=string.split(data.arrData[0][shift], ":")
-            h0=int(t[0])
-            m0=int(t[1])
-        except:
-            h0=int(strftime("%H", time.localtime()))
-            m0=int(strftime("%M", time.localtime()))
-#        print "Start time of graph:",  h0,  m0
-
-        
-        
-        
-        #draw Xscale
-        paint.setPen(QtGui.QColor("white"))
-        
-        #decade:
-        #6 => 60px/h
-        #1 => 360px/h
-        decade=360/Xscale
-        minutestonexthour=60-m0
-        offset=minutestonexthour*decade/60
-        
-        
-        Show_passed_time("2")
-        
-        #main lines + text
-        if(data.test==0):
-            for i in range(0, 781+decade,  decade):
-                paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
-                for k in range(1, 6):
-                    x=i+offset+k*decade/6-decade
-                    paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
-                h=(h0+int(i/decade)+1) % 24
-                paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 
-        else: #test mode, do not show X scale as it is wrong
-            paint.drawText(200, data.Ysize+20, "Test Mode")
-
-
-        #trigger line
-        y=(data.Ysize-(data.trigger*data.Yscale))-2
-        paint.drawLine(1, y-15, 781, y-15)  
-
-
-        Show_passed_time("4")
-
-        #draw graph
-        lastmove=0
-#        print shift,  data.arrDataIndex-data.derivation,  Xscale
-        
-        end=data.arrDataIndex-shift-data.derivation
-        peak=0   
-        for i in range(0,  end,  Xscale):
-            k=i+shift
-            
-            
-            
-            #when Xscale is small, we have to merge several records into 1 pixel.
-            #To not miss any movement, we use the biggest movement of the merged records:
-            peak=0            
-            paint.setPen(QtGui.QColor("yellow"))
-            for j in range(0, Xscale):
-#                Show_passed_time("L 1")
-                p=abs(data.arrData[3][k])+abs(data.arrData[4][k])
-                if(p>peak): peak=p
-           
-            
-            
-            
-#            if(1): #one or more movement for this pixel
-#                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
-            Y=peak*data.Yscale
-            #Draw movement line
-#            paint.setBrush(QtGui.QColor("yellow"))
-            paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
-            
-            
-            #fill space between yellow movement lines
-#                if(k>lastmove+1):k
-#            print i,  end,  Xscale
-            if(peak>data.trigger or i>=end-Xscale):
-#            if(peak>data.trigger):
-                
-                        
-                        
-#                Show_passed_time("L 2")
-##                    1=10 sec
-#                    if((i-lastmove)>30*Xscale): color="#009100" #green
-#                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
-#                    t=(i-lastmove)*Xscale
-#                    print t,  30*Xscale
-#                    if(t>30): color="#009100" #green
-#                    elif(t>15): color="#005000" #dark green
-#                    else: color="#6D0000" #dark red 
-
-                x0=lastmove/Xscale+1
-                x1=i/Xscale-1
-                if(x0<x1):
-                    t=(x1-x0)*Xscale/6          
-#                        print x0,  "<=>",  x1,  t,  Xscale
-                    if(t>30): color="#009100" #green
-                    elif(t>15): color="#005000" #dark green
-                    else: color="#6D0000" #dark red       
-                    print "draw rect with color",  color                  
-                    paint.setBrush(QtGui.QColor(color))
-                    paint.setPen(QtGui.QColor(color))
-                    paint.drawRect(x0, data.Ysize-11, x1-x0, 10)                     
-                    paint.setPen(QtGui.QColor("yellow"))
-#                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
-                lastmove=i
-                
-                
-        
-        if(peak>data.trigger): #if last value is over peak
-            if(data.Mode==1 and (end-data.derivation)>data.last_beep): #quick mode for testing but only once pr move
-                if(data.demo==0): #make beep for testing movement
-                    b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
-                    b.close()
-                    data.last_beep=end
-
-        Show_passed_time("showGraph End")
-
-
-
-
-
-###########################################################################
-# Delete an existing logfile
-###########################################################################
-def DeleteLogFile():
-    LogWindow.DeleteLogFile()
-
-
-def ShowLogFile():
-    OpenLogFile()    
-    ProcessData()
-    LogWindow.UpdateScreen()
-    LogWindowGraph = LogWindowCanvas()
-    data.Xscale=1 #default zoom level
-    data.ChangesInGraph=1 #Make sure it only gets refreshed once
-    LogWindowGraph.show()
-
-###########################################################################
-# Load next  logfile
-###########################################################################
-def NextLogFile():
-    LoadFileList(+1)
-    ShowLogFile()
-
-
-###########################################################################
-# Load last logfile
-###########################################################################
-def LastLogFile():
-    LoadFileList(-1)
-    ShowLogFile()
-
-
-###########################################################################
-# Close the window Notes
-###########################################################################
-def NotesClose():
-    StartWindow.show()
-    NoteWindow.close()
     
     
 ###########################################################################
-# Save the notes
+# Raise or lower the trigger in the graph + sleep phases
 ###########################################################################
-def NotesSave():
-    NoteWindow.SaveNotes()
-    NotesClose()
-
-
-
-
-
-
-
-
-
-
-
-
-
+def MoveTrigger(direction):
+    if(direction==+1): #up
+        data.trigger=data.trigger+1
+        if(data.trigger>data.maxtrigger): data.trigger=data.maxtrigger      
+        ProcessData()
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    else: #-1, down
+        data.trigger=data.trigger-1
+        if(data.trigger<0): data.trigger=0
+        ProcessData()
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
 
 
 
@@ -532,9 +228,9 @@ class frmStartWindow(QtGui.QWidget):
         self.ui = Ui_StartWindow()
         self.ui.setupUi(self)
 
-        QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), ShowCollectingWindow)
-        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)
-        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), ShowCollectingWindowTest)
+        QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
+        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
+        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowLogWindow)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"SleepAnalyser.png"))
@@ -542,6 +238,57 @@ class frmStartWindow(QtGui.QWidget):
             self.ui.bCollecting.setIcon(QIcon(data.app_path+"krec.png"))
             self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
 
+
+    ###########################################################################
+    # Show the collectring window (hera the data gets visualised during the logging)
+    ###########################################################################
+    def StartMeasurementNormal(self):
+        data.Mode=0 #run in normal mode
+        data.test=0 #show axis lables
+        self.StartMeasurement()
+        
+        
+    ###########################################################################
+    # Show the collectring window (hera the data gets visualised during the logging)
+    ###########################################################################
+    def StartMeasurementQuick(self):
+        data.Mode=1 #run in quick mode (for testing only)
+        data.Xscale=0 #default zoom level
+        data.test=1 #hide axis lables
+        self.StartMeasurement()
+        
+        
+    def StartMeasurement(self):
+        global CollectingWindowGraph
+        CollectingWindow.show()
+        StartWindow.hide()
+        CollectingWindowGraph = CollectingWindowCanvas()
+        StartMeasurement()
+        CollectingWindow.UpdateScreenStart()
+        CollectingWindowGraph.show()
+        
+        
+    ###########################################################################
+    # Show the log window (her ethe data from a file gets visualised)
+    ###########################################################################
+    def ShowLogWindow(self):
+        global LogWindowGraph
+        
+        tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+        tmp2=tmp.split("/")
+        l=len(tmp2)    
+        x=tmp2[l-1]
+        if(x==""): return #only continue if valid log file selected
+        data.logfilename=x
+        
+        LogWindowGraph = LogWindowCanvas()
+        LogWindow.ShowLogFile()
+        
+        LogWindow.show()
+        StartWindow.hide()
+        
+        
+
     def UpdateScreenStart(self):
         try:   
             print "Application path:",  data.app_path
@@ -565,6 +312,14 @@ class frmStartWindow(QtGui.QWidget):
 
 
 
+
+
+
+
+
+
+
+
 ###########################################################################
 #  Class for Collecting Window
 ###########################################################################
@@ -574,11 +329,11 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui = Ui_CollectingWindow()
         self.ui.setupUi(self)
         
-        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), ToggleMeasurement)
-        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), RaiseTrigger)
-        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
-        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), ZoomIn)
-        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), ZoomOut)
+        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), self.ToggleMeasurement)
+        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
+        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
+        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
+        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
@@ -597,6 +352,17 @@ class frmCollectingWindow(QtGui.QWidget):
         time_difference=t-data.StartTimeSec
         t=strftime("%H:%M:%S", time.gmtime(time_difference))
         self.ui.lblElapsedTime.setText(t)
+        self.ui.lblTrigger.setText(str(data.trigger))
+        
+        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
+        else: self.ui.bZoomIn.setEnabled(True)
+        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
+        else: self.ui.bZoomOut.setEnabled(True)
+
+        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
+        else: self.ui.bRaiseTrigger.setEnabled(True)
+        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
+        else: self.ui.bLowerTrigger.setEnabled(True)
             
 
     def UpdateScreenStart(self):
@@ -606,10 +372,12 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("00:00:00")
         self.ui.lblYscale.setText(str(data.Yscale))
-        self.ui.lblTrigger.setText(str(data.trigger*data.Yscale))
+        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"krec2.png"))
         self.ui.bStop.setText("Stop recording")
+
+        self.UpdateScreen()
         
         
     def UpdateScreenStop(self):
@@ -617,7 +385,51 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.bStop.setIcon(QIcon(data.app_path+"krec.png"))
         self.ui.bStop.setText("Start recording")
         
+        
+    def ToggleMeasurement(self):
+        global app
+        if(data.run==0): #not running
+            StartMeasurement()
+            self.UpdateScreenStart()
+        else: #running
+            StopMeasurement()
+            self.UpdateScreenStop()
+            data.test=0 # reset test mode if was active
+        
+        
+        
+    def ZoomIn(self):
+        Zoom(+1)
+#        self.ui.bZoomOut.setEnabled(True)
+#        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
+#        else: self.ui.bZoomIn.setEnabled(True)
+        self.update()
+        self.UpdateScreen()
 
+    def ZoomOut(self):
+        r=Zoom(-1)
+#        self.ui.bZoomIn.setEnabled(True)
+#        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
+#        else: self.ui.bZoomOut.setEnabled(True)
+        self.update()
+        self.UpdateScreen()
+
+
+    def RaiseTrigger(self):   
+        MoveTrigger(+1)
+        self.ui.bLowerTrigger.setEnabled(True)
+        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
+        else: self.ui.bRaiseTrigger.setEnabled(True)
+        self.update() 
+        self.UpdateScreen()
+        
+    def LowerTrigger(self):     
+        MoveTrigger(-1)
+        self.ui.bRaiseTrigger.setEnabled(True)
+        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
+        else: self.ui.bLowerTrigger.setEnabled(True)
+        self.update()
+        self.UpdateScreen()
 
 
     def closeEvent(self, event):
@@ -627,10 +439,10 @@ class frmCollectingWindow(QtGui.QWidget):
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
             
-        if(data.run==1): ToggleMeasurement()
+        if(data.run==1): StopMeasurement()
         StartWindow.show()
 #        NoteWindow.show()
-        CollectingWindow.close() 
+        self.close() 
 
 
    
@@ -650,13 +462,13 @@ class frmLogWindow(QtGui.QWidget):
         self.ui = Ui_LogWindow()
         self.ui.setupUi(self)
         
-        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), RaiseTrigger)
-        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
-        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), ZoomIn)
-        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), ZoomOut)
-        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), NextLogFile)
-        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), LastLogFile)
-        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)
+        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
+        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
+        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
+        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
+        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextLogFile)
+        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
+        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bLast.setIcon(QIcon(data.app_path+"go-previous.png"))
@@ -674,9 +486,83 @@ class frmLogWindow(QtGui.QWidget):
         self.ui.lblLogfile.setText(data.logfilename)
         self.ui.lblStarttime.setText(str(data.arrData[0][0]))
         self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
-        self.ui.lblTrigger.setText(str(data.trigger*data.Yscale))
+        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblYscale.setText(str(data.Yscale))
 
+        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
+        else: self.ui.bZoomIn.setEnabled(True)
+        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
+        else: self.ui.bZoomOut.setEnabled(True)
+
+        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
+        else: self.ui.bRaiseTrigger.setEnabled(True)
+        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
+        else: self.ui.bLowerTrigger.setEnabled(True)
+
+
+
+    def ShowLogFile(self):
+        OpenLogFile()    
+        LoadFileList()
+        ProcessData()
+        data.Xscale=1 #default zoom level
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+        LogWindowGraph = LogWindowCanvas()
+        LogWindowGraph.show()
+        self.UpdateScreen()
+        
+        
+    ###########################################################################
+    # Load next  logfile
+    ###########################################################################
+    def NextLogFile(self):
+        data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
+        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+        self.ShowLogFile()
+
+
+    ###########################################################################
+    # Load last logfile
+    ###########################################################################
+    def LastLogFile(self):
+        data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
+        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+        self.ShowLogFile()
+
+
+        
+    def ZoomIn(self):
+        Zoom(+1)
+        self.ui.bZoomOut.setEnabled(True)
+        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
+        else: self.ui.bZoomIn.setEnabled(True)
+        self.update()
+
+    def ZoomOut(self):
+        r=Zoom(-1)
+        self.ui.bZoomIn.setEnabled(True)
+        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
+        else: self.ui.bZoomOut.setEnabled(True)
+        self.update()
+        
+        
+
+    def RaiseTrigger(self):   
+        MoveTrigger(+1)
+#        self.ui.bLowerTrigger.setEnabled(True)
+#        if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
+#        else: self.ui.bRaiseTrigger.setEnabled(True)
+        self.update() 
+        self.UpdateScreen()
+        
+    def LowerTrigger(self):     
+        MoveTrigger(-1)
+#        self.ui.bRaiseTrigger.setEnabled(True)
+#        if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
+#        else: self.ui.bLowerTrigger.setEnabled(True)
+        self.update()
+        self.UpdateScreen()
+   
 
     def DeleteLogFile(self):
         reply = QtGui.QMessageBox.question(self, 'Delete Logfile?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
@@ -685,13 +571,11 @@ class frmLogWindow(QtGui.QWidget):
             os.remove(data.logfolder+data.logfilename)    
             data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
             data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
-            ShowLogFile()
+            self.ShowLogFile()
 
 
 
     def closeEvent(self, event):
-#        self.ui.cZoom.setChecked(False)
-#        Zoom()
         config.set('main', 'trigger', str(data.trigger))      
         LogWindow.close()
         StartWindow.show()
@@ -715,14 +599,22 @@ class frmNoteWindow(QtGui.QWidget):
         self.ui = Ui_NoteWindow()
         self.ui.setupUi(self)
         
-        QtCore.QObject.connect(self.ui.bClose, QtCore.SIGNAL("clicked()"), NotesClose)
-        QtCore.QObject.connect(self.ui.bSave, QtCore.SIGNAL("clicked()"), NotesSave)
+        QtCore.QObject.connect(self.ui.bClose, QtCore.SIGNAL("clicked()"), self.NotesClose)
+        QtCore.QObject.connect(self.ui.bSave, QtCore.SIGNAL("clicked()"), self.NotesSave)
         
         
     def SaveNotes(self):
         txt=""
         if(self.ui.cFeedback1.isChecked()==true):
             pass
+            
+    def NotesClose(self):
+        StartWindow.show()
+        NoteWindow.close()
+        
+    def NotesSave(self):
+        NoteWindow.SaveNotes()
+        NotesClose()
 
     def closeEvent(self, event):
         NoteWindow.close()
@@ -747,7 +639,7 @@ class CollectingWindowCanvas(QtGui.QWidget):
         self.setGeometry(9, 180, 782, data.Ysize+30)
     
     def paintEvent(self, event):
-        showGraph(self)
+        showGraph(self,  QtGui)
 
 
 
@@ -764,7 +656,7 @@ class LogWindowCanvas(QtGui.QWidget):
         self.setGeometry(9, 100, 782, data.Ysize+30)
     
     def paintEvent(self, event):
-        showGraph(self)
+        showGraph(self,  QtGui)
     
     
     
