@@ -11,6 +11,7 @@ import ConfigParser
 import os, os.path
 
 import data
+from myFunctions2 import * #Own functions
 
 
 ###########################################################################
@@ -78,7 +79,7 @@ def StopLogfile():
 ###########################################################################
 #  Load list of log files into array
 ###########################################################################
-def LoadFileList(dir):
+def LoadFileList():
     Show_passed_time("LoadFileList Start")
     print "Load file list"
     output = os.popen("cd "+data.logfolder+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
@@ -91,8 +92,6 @@ def LoadFileList(dir):
         for i in range(len(data.arrLogFiles)):
             if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
             
-    data.arrLogFileIndex=(data.arrLogFileIndex+dir)  % len(data.arrLogFiles)
-    data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
     Show_passed_time("LoadFileList End")
 
 
@@ -206,120 +205,3 @@ def WriteConfig(config):
     
     
 
-###########################################################################
-# Read the sensor data x times and smoothen it
-###########################################################################
-def ReadAccSensor():    
-    coords=[0, 0]    
-    if(data.demo==0):        
-        for i in range(data.sample_smoothing):
-            f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
-            coords_tmp = [int(w) for w in f.readline().split()]
-            f.close()
-            coords[0]=coords[0] + coords_tmp[0] #X
-            coords[1]=coords[1] + coords_tmp[1] #Y
-        coords[0]=coords[0] / data.sample_smoothing
-        coords[1]=coords[1] / data.sample_smoothing
-    else:
-        coords[0]=int(random.uniform(-50,50))
-        coords[1]=int(random.uniform(-50,50))
-
-    print coords[0],  coords[1]
-    return coords
-
-
-
-
-
-
-
-
-###########################################################################
-# Get the smoothened sensor data, smoothen it again and fill the data into the main data array
-###########################################################################
-def GetSensorData():    
-    d=ReadAccSensor()
-    data.arrDataTemp[0]=data.arrDataTemp[0]+d[0]
-    data.arrDataTemp[1]=data.arrDataTemp[1]+d[1]
-
-    data.sample_index=data.sample_index+1
-    
-    if(data.sample_index==data.value_smoothing): #if is 10 runs over        
-        data.sample_index=0
-        data.arrDataIndex=data.values_total % data.arrDataLen
-        data.values_total=data.values_total+1
-        
-        data.arrData[0][data.arrDataIndex]=strftime("%H:%M:%S", time.localtime())
-        data.arrData[1][data.arrDataIndex]=data.arrDataTemp[0]/data.value_smoothing
-        data.arrData[2][data.arrDataIndex]=data.arrDataTemp[1]/data.value_smoothing
-
-        data.arrDataTemp[0]=0
-        data.arrDataTemp[1]=0
-
-        print "smoothened:",  data.arrData[1][data.arrDataIndex],  data.arrData[2][data.arrDataIndex]
-        return 1 #added new values to arrData     (interval: sampling*sample_smoothing*value_smoothing)
-    else: return 0 #no new data added
-
-
-
-
-
-
-
-
-
-
-
-
-###########################################################################
-#  Process the data, generate movement indication
-###########################################################################
-def ProcessData():
-    #DERIVATION (ABLEITUNG)
-    Show_passed_time("ProcessData Start")
-#        print i,  data.arrData[0][i] ,  data.arrData[1][i],  data.arrData[2][i]  
-    for i in range(0, data.arrDataIndex-data.derivation):
-        data.arrData[3][i]=data.arrData[1][i+data.derivation] - data.arrData[1][i] #X  in 5 sec - X now
-        data.arrData[4][i]=data.arrData[2][i+data.derivation] - data.arrData[2][i] #Y  in 5 sec - Y now
-#        print i,  i+data.derivation,  data.arrData[3][i],  data.arrData[4][i]
-
-
-#    lastmovement=0
-#    for i in range(0, data.arrDataIndex-data.derivation):
-##        data.arrData[6][i]=lastmovement
-#        if((abs(data.arrData[3][i])+abs(data.arrData[4][i]))>data.trigger):
-#            data.arrData[5][i]=1
-##            lastmovement=i
-#        else:
-#            data.arrData[5][i]=0
-
-
-
-#debug
-#    for i in range(0, data.arrDataIndex-data.derivation):
-#        if(data.arrData[5][i]==1): x="======="
-#        else: x="|"
-#        print i,  data.arrData[0][i],  data.arrData[4][i],  data.arrData[5][i],  data.arrData[6][i],  x
-#
-
-    Show_passed_time("ProcessData End")
-
-
-
-
-
-
-###########################################################################
-# Function to measure used time in a function
-###########################################################################
-def Show_passed_time(text=""):
-#    global passed_time
-    if(data.debug==0): return
-    now=time.time()
-    t=1000*(now-data.passed_time)
-    print "+++++++++",  str(int(t)), "ms: ", text
-
-    data.passed_time = time.time()
-
-
-
